@@ -16,13 +16,16 @@ typedef struct {
   PyObject *parent;
 } py_block;
 
+#define PY_DSP(x) (&(((py_dsp *) (x))->vd))
+#define PY_BLOCK(x) (&(((py_block *) (x))->vb))
+
 extern PyTypeObject py_dsp_type;
 extern PyTypeObject py_block_type;
 
 PyObject *py_dsp_from_dsp(vorbis_dsp_state *vd, PyObject *parent);
 PyObject *py_block_from_block(vorbis_block *vb, PyObject *parent);
 
-#endif //__VORBISCODEC_H__
+#endif /* __VORBISCODEC_H__ */
 
 
 
