@@ -173,8 +173,7 @@ py_file_new(PyObject *self, PyObject *args) /* change to accept kwarg */
   if (ret == NULL) {
     PyMem_DEL(newobj);
     return NULL;
-  } else
-    Py_DECREF(ret);
+  }
 
   return (PyObject *) newobj;
 }
@@ -191,11 +190,13 @@ py_ov_file_dealloc(PyObject *self)
        close */
     Py_DECREF(py_self->py_file);
   } else {
-    /* Otherwise, we opened the file and should close it. */
-    fclose(py_self->c_file);
+    /* Do NOT close the file -- ov_open() takes ownership of the FILE*,
+       and ov_close() is responsible for closing it. */
   }
 
-  PyMem_DEL(self);
+  free(py_self->ovf);
+
+  PyObject_DEL(self);
 }
 
 static PyObject *
